@@ -2,13 +2,15 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .account import *
-from .stock import *
+
+from . import account, stock
 
 
 def register():
     Pool.register(
-        InvoiceLineStockMove,
-        InvoiceLine,
-        StockMove,
+        account.Invoice,
+        account.InvoiceLineStockMove,
+        account.InvoiceLine,
+        stock.Move,
+        stock.ShipmentOut,
         module='account_invoice_stock', type_='model')
